@@ -2323,7 +2323,7 @@ enum
 };
 
 /* Define CC and CFLAGS which were used to build this version of GMP */
-#define __GMP_CC "cc"
+#define __GMP_CC "/usr/bin/gcc"
 #define __GMP_CFLAGS "--target=x86_64-apple-darwin"
 
 /* Major version number is the value of __GNU_MP__ too, above. */
